"""A linter for alidist recipes.

Combines shellcheck for recipes with yamllint and some internal checks for a
recipe's YAML header.
"""
